*********************
Major Release History
*********************

|Milestones| |Open Issues| |Last GitHub Release|

Examples in these documents are frozen in time to respect the status of the API at the time of the release they are describing. Please refer to the main, up-to-date documentation if you run into any issues with the functionality highlighted in these pages.


.. toctree::
   :maxdepth: 1

   1.0


Full Change-log:

.. toctree::
   :maxdepth: 1

   CHANGES


Planned Features:

.. toctree::
   :maxdepth: 1

   planned


.. |Milestones| image:: https://img.shields.io/github/milestones/open/nstarman/utilipy?style=flat
   :alt: GitHub milestones
.. |Open Issues| image:: https://img.shields.io/github/issues-raw/nstarman/utilipy?style=flat
   :alt: GitHub issues
.. |Last GitHub Release| image:: https://img.shields.io/github/release-date/nstarman/utilipy?style=flat
   :alt: GitHub Release Date
